'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _assign = require('babel-runtime/core-js/object/assign');

var _assign2 = _interopRequireDefault(_assign);

var _hash = require('./hash');

var _hash2 = _interopRequireDefault(_hash);

var _hostname = require('./hostname');

var _hostname2 = _interopRequireDefault(_hostname);

var _validate = require('./validate');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

// Hash the input for the requested number of rounds, then continue hashing
// until the password policy is satisfied. Finally, pass result to callback.
function hashRound(input, length, hashFunction, rounds, callback) {
  if (rounds > 0 || !(0, _validate.validatePassword)(input, length)) {
    process.nextTick(function () {
      hashRound(hashFunction(input), length, hashFunction, rounds - 1, callback);
    });
    return;
  }
  process.nextTick(function () {
    callback(input.substring(0, length));
  });
} /*!
   * SuperGenPass library
   * https://github.com/chriszarate/supergenpass-lib
   * https://chriszarate.github.com/supergenpass/
   * License: GPLv2
   */

function generate(masterPassword, url) // eslint-disable-line no-console
{
  var userOptions = arguments.length <= 2 || arguments[2] === undefined ? {} : arguments[2];
  var callback = arguments.length <= 3 || arguments[3] === undefined ? console.log : arguments[3];

  var defaults = {
    hashRounds: 10,
    length: 10,
    method: 'md5',
    removeSubdomains: true,
    secret: ''
  };
  var options = (0, _assign2.default)({}, defaults, userOptions);

  (0, _validate.validateCallback)(callback);
  (0, _validate.validatePasswordInput)(masterPassword);
  (0, _validate.validatePasswordInput)(options.secret);
  (0, _validate.validatePasswordLength)(masterPassword + options.secret);
  (0, _validate.validateLength)(options.length);

  var domain = (0, _hostname2.default)(url, options);
  var input = '' + masterPassword + options.secret + ':' + domain;

  hashRound(input, options.length, (0, _hash2.default)(options.method), options.hashRounds, callback);
}

exports.default = generate;