'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _assign = require('babel-runtime/core-js/object/assign');

var _assign2 = _interopRequireDefault(_assign);

var _tldList = require('./tld-list');

var _tldList2 = _interopRequireDefault(_tldList);

var _endsWith = require('babel-runtime/core-js/string/ends-with');

var _endsWith2 = _interopRequireDefault(_endsWith);

var _find = require('babel-runtime/core-js/array/find');

var _find2 = _interopRequireDefault(_find);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

// Remove subdomains while respecting a number of secondary ccTLDs.
function removeSubdomains(hostname) {
  var hostnameParts = hostname.split('.');

  // A hostname with less than three parts is as short as it will get.
  if (hostnameParts.length < 2) {
    return hostname;
  }

  // Try to find a match in the list of ccTLDs.
  var ccTld = (0, _find2.default)(_tldList2.default, function (part) {
    return (0, _endsWith2.default)(hostname, part);
  });
  if (ccTld) {
    // Get one extra part from the hostname.
    var partCount = ccTld.split('.').length + 1;
    return hostnameParts.slice(0 - partCount).join('.');
  }

  // If no ccTLDs were matched, return the final two parts of the hostname.
  return hostnameParts.slice(-2).join('.');
}

// Isolate the domain name of a URL.
/*!
 * SuperGenPass library
 * https://github.com/chriszarate/supergenpass-lib
 * https://chriszarate.github.com/supergenpass/
 * License: GPLv2
 */

function getHostname(url) {
  var userOptions = arguments.length <= 1 || arguments[1] === undefined ? {} : arguments[1];

  var defaults = {
    removeSubdomains: true
  };
  var options = (0, _assign2.default)({}, defaults, userOptions);
  var domainRegExp = /^(?:[a-z]+:\/\/)?(?:[^/@]+@)?([^/:]+)/i;
  var ipAddressRegExp = /^\d{1,3}\.\d{1,3}.\d{1,3}\.\d{1,3}$/;
  var domainMatch = url.match(domainRegExp);

  if (domainMatch === null) {
    throw new Error('URL is invalid: ' + url);
  }

  // If the hostname is an IP address, no further processing can be done.
  var hostname = domainMatch[1];
  if (ipAddressRegExp.test(hostname)) {
    return hostname;
  }

  // Return the hostname with subdomains removed, if requested.
  return options.removeSubdomains ? removeSubdomains(hostname) : hostname;
}

exports.default = getHostname;