'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.validatePasswordLength = exports.validatePasswordInput = exports.validatePassword = exports.validateLength = exports.validateCallback = undefined;

var _typeof2 = require('babel-runtime/helpers/typeof');

var _typeof3 = _interopRequireDefault(_typeof2);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/*!
 * SuperGenPass library
 * https://github.com/chriszarate/supergenpass-lib
 * https://chriszarate.github.com/supergenpass/
 * License: GPLv2
 */

function validateCallback(callback) {
  if (typeof callback !== 'function') {
    throw new Error('Must provide callback function.');
  }
}

function validateLength(num) {
  if (num !== parseInt(num, 10) || num < 4 || num > 24) {
    throw new Error('Length must be an integer between 4 and 24: ' + num + '.');
  }
}

function validatePassword(str, length) {
  // Cut password to requested length.
  var password = str.substring(0, length);

  // 1. Password must start with a lowercase letter [a-z].
  // 2. Password must contain at least one uppercase letter [A-Z].
  // 3. Password must contain at least one numeral [0-9].
  var startsWithLowercaseLetter = /^[a-z]/;
  var containsUppercaseLetter = /[A-Z]/;
  var containsNumeral = /[0-9]/;

  // Return true if all tests are satisfied.
  return startsWithLowercaseLetter.test(password) && containsUppercaseLetter.test(password) && containsNumeral.test(password);
}

function validatePasswordInput(str) {
  if (typeof str !== 'string') {
    throw new Error('Password must be a string, received ' + (typeof str === 'undefined' ? 'undefined' : (0, _typeof3.default)(str)) + '.');
  }
}

function validatePasswordLength(str) {
  if (!str.length) {
    throw new Error('Combined password input must not be empty.');
  }
}

exports.validateCallback = validateCallback;
exports.validateLength = validateLength;
exports.validatePassword = validatePassword;
exports.validatePasswordInput = validatePasswordInput;
exports.validatePasswordLength = validatePasswordLength;